document.addEventListener('DOMContentLoaded', function() {
  console.log('DOM Content Loaded');

  var forms = document.querySelectorAll('form[data-form-submit]');
  console.log('Found ' + forms.length + ' forms with data-form-submit attribute');

  for (var i = 0; i < forms.length; i++) {
    console.log('Attaching submit event listener to form ' + (i+1));

    forms[i].addEventListener('submit', function(event) {
      console.log('Form submit event triggered');
      event.preventDefault();

      var form = this;
      var submitButton = form.querySelector('input[type="submit"]');
      var formData = new FormData(form);
      var formSubmitType = form.getAttribute('data-form-submit');
      formData.append('formSubmitType', formSubmitType);

      console.log('Form submit type: ' + formSubmitType);

      if (form.getAttribute('data-form-submitted') !== 'true') {
        console.log('Form not yet submitted');
        form.setAttribute('data-form-submitted', 'true');
        submitButton.disabled = true;
        console.log('Sending form via AJAX');
        sendForm(form, new URLSearchParams(formData), submitButton);
      } else {
        console.log('Form already submitted, preventing duplicate submission');
      }
    });
  }
});

window.userFeedback = {
  selectAnswer: function(index, instanceCount) {
    document.getElementById('answerValue' + instanceCount).value = index + 1;
    document.getElementById('commentSection' + instanceCount).style.display = 'block';
    var answerButtons = document.querySelectorAll('#userFeedbackForm' + instanceCount + ' button');
    answerButtons.forEach(function(button, i) {
      if (i === index) {
        button.classList.add('active');
      } else {
        button.classList.remove('active');
      }
    });
    this.submitUserFeedbackForm(document.getElementById('userFeedbackForm' + instanceCount));
  },

  startCommentTimeout: function(instanceCount) {
    clearTimeout(this.commentTimeouts[instanceCount]);
    this.commentTimeouts[instanceCount] = setTimeout(function() {
      window.userFeedback.submitUserFeedbackForm(document.getElementById('userFeedbackForm' + instanceCount), true);
    }, 500);
  },

  submitUserFeedbackForm: function(form, isUpdate = false) {
    var instanceCount = form.id.match(/\d+/)[0];
    document.getElementById('userRandomHash' + instanceCount).value = localStorage.getItem('randomHash') || '';
    document.getElementById('canonicalURL' + instanceCount).value = document.querySelector('.url-info').dataset.canonicalUrl;

    var formData = new FormData(form);
    var xhr = new XMLHttpRequest();
    xhr.open(form.method, form.action);
    xhr.onload = function() {
      if (xhr.status === 200) {
        var response = JSON.parse(xhr.responseText);
        var messageContainerId = isUpdate ? 'commentMessages' + instanceCount : 'answerMessages' + instanceCount;
        var messageContainer = document.getElementById(messageContainerId);
        var successMessage = messageContainer.querySelector('.success-message');
        var updateMessage = messageContainer.querySelector('.update-message');
        var errorMessage = messageContainer.querySelector('.error-message');

        if (isUpdate) {
          if (response.status === 'success') {
            if (updateMessage) {
              updateMessage.style.display = 'block';
            }
            if (errorMessage) {
              errorMessage.style.display = 'none';
            }
          } else {
            if (updateMessage) {
              updateMessage.style.display = 'none';
            }
            if (errorMessage) {
              errorMessage.style.display = 'block';
            }
          }
        } else {
          if (response.status === 'success') {
            if (successMessage) {
              successMessage.style.display = 'block';
            }
            if (errorMessage) {
              errorMessage.style.display = 'none';
            }
          } else {
            if (successMessage) {
              successMessage.style.display = 'none';
            }
            if (errorMessage) {
              errorMessage.style.display = 'block';
            }
          }
        }

        setTimeout(function() {
          if (successMessage) {
            successMessage.style.display = 'none';
          }
          if (updateMessage) {
            updateMessage.style.display = 'none';
          }
          if (errorMessage) {
            errorMessage.style.display = 'none';
          }
        }, 5000);
      } else {
        var messageContainerId = isUpdate ? 'commentMessages' + instanceCount : 'answerMessages' + instanceCount;
        var messageContainer = document.getElementById(messageContainerId);
        var errorMessage = messageContainer.querySelector('.error-message');
        if (errorMessage) {
          errorMessage.style.display = 'block';
          setTimeout(function() {
            errorMessage.style.display = 'none';
          }, 5000);
        }
      }
    };
    xhr.send(formData);
  },

  commentTimeouts: {}
};

function sendForm(form, formData, submitButton) {
  console.log('Sending form data via XMLHttpRequest');

  var xhr = new XMLHttpRequest();
  xhr.open('POST', window.location.href, true);
  xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
  xhr.setRequestHeader('X-Requested-With', 'XMLHttpRequest');

  xhr.onreadystatechange = function() {
    if (xhr.readyState === 4) {
      console.log('XHR readyState 4 - request complete');
      if (xhr.status === 200) {
        console.log('XHR status 200 - successful response');
        var response = xhr.responseText;

        var escapedPostData;
        try {
          escapedPostData = JSON.parse(response);
          console.log('Parsed escapedPostData:', escapedPostData);
        } catch (error) {
          console.error('Error parsing JSON response:', error);
          console.log('Full response from server:', response);
        }

        var mailSent = escapedPostData && escapedPostData.hasOwnProperty('mail_sent') ? escapedPostData.mail_sent : null;

        var messageElement = form.querySelector('[data-message]');
        if (messageElement) {
          var successMessage = messageElement.getAttribute('data-success-message');
          var errorMessage = messageElement.getAttribute('data-error-message');
          var successColor = messageElement.getAttribute('data-success-color');
          var errorColor = messageElement.getAttribute('data-error-color');

          if (mailSent === 1) {
            console.log('Mail sent successfully');
            messageElement.innerHTML = successMessage;
            messageElement.style.color = successColor;
          } else if (mailSent === 0) {
            console.error('Error sending mail');
            messageElement.innerHTML = errorMessage;
            messageElement.style.color = errorColor;
            form.setAttribute('data-form-submitted', 'false');
            submitButton.disabled = false;
          } else {
            console.warn('mail_sent status is undefined or has an unexpected value:', mailSent);
            messageElement.innerHTML = errorMessage;
            messageElement.style.color = errorColor;
            form.setAttribute('data-form-submitted', 'false');
            submitButton.disabled = false;
          }
        } else {
          console.warn('No message element found to display status');
        }
      } else {
        console.error('Error in AJAX request. Status: ' + xhr.status);
        form.setAttribute('data-form-submitted', 'false');
        submitButton.disabled = false;
      }
    }
  };

  console.log('Sending XHR with form data');
  xhr.send(formData);
}
